@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */
 
 #include "mutt.h"
@@ -101,13 +101,8 @@ void mutt_edit_headers (const char *editor,
   mutt_free_envelope (&msg->env);
   msg->env = n;
 
-  msg->env->from = mutt_expand_aliases (msg->env->from);
-  msg->env->to = mutt_expand_aliases (msg->env->to);
-  msg->env->cc = mutt_expand_aliases (msg->env->cc);
-  msg->env->bcc = mutt_expand_aliases (msg->env->bcc);
-  msg->env->reply_to = mutt_expand_aliases (msg->env->reply_to);
-  msg->env->mail_followup_to = mutt_expand_aliases (msg->env->mail_followup_to);
-
+  mutt_expand_aliases_env (msg->env);
+  
   /* search through the user defined headers added to see if either a 
    * fcc: or attach-file: field was specified.  
    */
