@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */
 #include <openssl/ssl.h>
 #include <openssl/x509.h>
@@ -191,8 +191,7 @@ static int ssl_check_certificate (sslsockdata * data)
   char *line = NULL, *c;
 
   /* automatic check from user's database */
-  fp = fopen (SslCertFile, "rt");
-  if (fp)
+  if ((fp = fopen (SslCertFile, "rt")))
   {
     EVP_PKEY *peer = X509_get_pubkey (data->cert);
     X509 *savedkey = NULL;
@@ -269,8 +268,7 @@ static int ssl_check_certificate (sslsockdata * data)
         break;
       case OP_MAX + 3:		/* accept always */
         done = 0;
-	fp = fopen (SslCertFile, "w+t");
-	if (fp)
+        if ((fp = fopen (SslCertFile, "w+t")))
 	{
 	  if (PEM_write_X509 (fp, data->cert))
 	    done = 1;
