@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 #include "mutt.h"
@@ -868,6 +868,8 @@ static ADDRESS *set_reverse_name (ENVELOPE *env)
   if (tmp)
   {
     tmp = rfc822_cpy_adr_real (tmp);
+    if (!option (OPTREVREAL))
+      FREE (&tmp->personal);
     if (!tmp->personal)
       tmp->personal = safe_strdup (Realname);
   }
@@ -1040,9 +1042,7 @@ ci_send_message (int flags,		/* send mode */
 
   if (msg)
   {
-    msg->env->to = mutt_expand_aliases (msg->env->to);
-    msg->env->cc = mutt_expand_aliases (msg->env->cc);
-    msg->env->bcc = mutt_expand_aliases (msg->env->bcc);
+    mutt_expand_aliases_env (msg->env);
   }
   else
   {
