@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 #include "mutt.h"
@@ -33,7 +33,9 @@ static sort_t *AuxSort = NULL;
   set_option(OPTAUXSORT); \
   code = AuxSort(a,b); \
   unset_option(OPTAUXSORT); \
-}
+} \
+if (!code) \
+  code = (*((HEADER **)a))->index - (*((HEADER **)b))->index;
 
 int compare_score (const void *a, const void *b)
 {
@@ -201,12 +203,13 @@ void mutt_sort_headers (CONTEXT *ctx, int init)
   if (init)
     mutt_clear_threads (ctx);
 
-  if (option (OPTNEEDRESCORE))
+  if (option (OPTNEEDRESCORE) && option (OPTSCORE))
   {
     for (i = 0; i < ctx->msgcount; i++)
-      mutt_score_message (ctx->hdrs[i]);
-    unset_option (OPTNEEDRESCORE);
+      mutt_score_message (ctx, ctx->hdrs[i], 1);
   }
+  unset_option (OPTNEEDRESCORE);
+
 
   if ((Sort & SORT_MASK) == SORT_THREADS)
   {
